@@ -2,7 +2,7 @@
 
 /* Purpose: Conform variable types */
 
-/* Copyright (C) 1995--2018 Charlie Zender
+/* Copyright (C) 1995--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
@@ -11,8 +11,8 @@
 
 void
 cast_void_nctype /* [fnc] Cast generic pointer to netCDF type */
-(const nc_type type, /* I [enm] netCDF type to cast void pointer to*/
- ptr_unn * const ptr) /* I/O [ptr] Pointer to pointer union whose vp element will be cast to type type*/
+(const nc_type type, /* I [enm] netCDF type to cast void pointer to */
+ ptr_unn * const ptr) /* I/O [ptr] Pointer to pointer union whose vp element will be cast to type type */
 {
   /* Purpose: Cast generic pointer in ptr_unn structure from type void to output netCDF type */
   switch(type){
@@ -52,6 +52,18 @@ cast_void_nctype /* [fnc] Cast generic pointer to netCDF type */
   case NC_STRING:
     ptr->sngp=(nco_string *)ptr->vp;
     break;
+  case NC_VLEN:
+    ptr->vlnp=(nco_vlen *)ptr->vp;
+    break;
+  case NC_OPAQUE:
+    ptr->opqp=(nco_opaque *)ptr->vp;
+    break;
+  case NC_ENUM:
+    ptr->enmp=(nco_enum *)ptr->vp;
+    break;
+  case NC_COMPOUND:
+    ptr->cpdp=(nco_compound *)ptr->vp;
+    break;
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
 } /* end cast_void_nctype() */
@@ -99,6 +111,18 @@ cast_nctype_void /* [fnc] Cast generic pointer in ptr_unn structure from type ty
   case NC_STRING:
     ptr->vp=(void *)ptr->sngp;
     break;
+  case NC_VLEN:
+    ptr->vp=(void *)ptr->vlnp;
+    break;
+  case NC_OPAQUE:
+    ptr->vp=(void *)ptr->opqp;
+    break;
+  case NC_ENUM:
+    ptr->vp=(void *)ptr->enmp;
+    break;
+  case NC_COMPOUND:
+    ptr->vp=(void *)ptr->cpdp;
+    break;
   default: nco_dfl_case_nc_type_err(); break;
   } /* end switch */
 } /* end cast_nctype_void() */
@@ -848,6 +872,10 @@ nco_val_cnf_typ /* [fnc] Copy val_in and typecast from typ_in to typ_out */
      val_out must hold enough space (one element of type typ_out) to hold output
      and output type may be larger than input type */
 
+  /* 20180509: Unsure why it is unsafe to return immediately when typ_in == typ_out
+     However, doing so causes dozens of regression failures */
+  //  if(typ_in == typ_out) return;
+
   /* Typecast pointer to values before access */
   (void)cast_void_nctype(typ_in,&val_in);
   (void)cast_void_nctype(typ_out,&val_out);
