@@ -2,7 +2,7 @@
 
 /* Purpose: NCO wrappers for netCDF C library */
 
-/* Copyright (C) 1995--2018 Charlie Zender
+/* Copyright (C) 1995--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
@@ -10,7 +10,7 @@
 /* Usage:
 #include "nco_netcdf.h" *//* NCO wrappers for netCDF C library */
 
-/* nco_netcdf.h is (nearly) independent of NCO and does not depend on nco.h
+/* nco_netcdf.h is (nearly) independent of NCO and does NOT depend on nco.h
    nco_netcdf.h is an abstraction layer for netcdf.h, plus a few convenience routines
    A similar abstraction layer must exist for each NCO storage backend, e.g., nco_hdf.h
 
@@ -228,6 +228,9 @@
 # define NC_EFILLVALUE    (-122)    /**< Attempt to define fill value when data already exists. */
 #endif /* !HAVE_NETCDF4_H */
 
+/* define MAX CHUNK SIZE here as its not present in netcdf.h */
+#define NCO_MAX_CHUNK_SIZE (0xFFFFFFFF)
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -340,16 +343,23 @@ int ncompi_open  (MPI_Comm mpi_cmm,const char * const fl_nm,const int omode,MPI_
 #endif /* !ENABLE_MPI */
 
   /* This bunch of pre-processor definitions is ugly
-     NC_LIB_VERSION could be replaced by an autoconf-generated token that checked for existance of, e.g., nc_open_memio() */
+     NC_LIB_VERSION should be replaced by an autoconf-generated token that checked for existance of, e.g., nc_open_memio()
+     However netCDF 4.6.2 netcdf_mem.h has EXTERNL without a definition so autoconf checks fail */
 #if NC_LIB_VERSION >= 462 
 # include <netcdf_mem.h> /* NC_memio, nc_open_mem(), nc_open_memio()... */
 #else /* 4.6.2 */
+  /* 20181206: Appveyor on Windows fails due to redefinition of NC_memio
+     Unsure exactly why it is defined twice for netCDF library <= 4.6.1 */
+# ifndef NETCDF_MEM_H
+  /* 20190130: struct NC_memio first defined in netcdf_mem.h in 4.6.2
+     Define it here to use in stub functions compiled against earlier netCDF libraries */
 typedef struct NC_memio {
   size_t size;
   void* memory;
   int flags;
 # define NC_MEMIO_LOCKED 1    /* Do not try to realloc or free provided memory */
 } NC_memio;
+# endif /* NETCDF_MEM_H */
 #endif /* 4.6.2 */
 
   /* Begin file-level routines */
