@@ -2,7 +2,7 @@
 
 /* Purpose: NCO utilities for Precision-Preserving Compression (PPC) */
 
-/* Copyright (C) 2015--2018 Charlie Zender
+/* Copyright (C) 2015--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
@@ -605,9 +605,12 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   
   /* Use constants defined in math.h */
   const double bit_per_dcm_dgt_prc=M_LN10/M_LN2; /* 3.32 [frc] Bits per decimal digit of precision */
+  const double dcm_per_bit_dgt_prc=M_LN2/M_LN10; /* 0.301 [frc] Bits per decimal digit of precision */
   
   const int bit_xpl_nbr_sgn_flt=23; /* [nbr] Bits 0-22 of SP significands are explicit. Bit 23 is implicitly 1. */
   const int bit_xpl_nbr_sgn_dbl=53; /* [nbr] Bits 0-52 of DP significands are explicit. Bit 53 is implicitly 1. */
+  const int ieee_xpn_fst_flt=127; /* [nbr] IEEE "exponent bias" = actual exponent minus stored ponent */
+  const int ieee_xpn_fst_dbl=1023; /* [nbr] IEEE "exponent bias" = actual exponent minus stored ponent */
   
   double prc_bnr_xct; /* [nbr] Binary digits of precision, exact */
   
@@ -703,6 +706,73 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
 	for(idx=0L;idx<sz;idx++)
 	  if(op1.fp[idx] != mss_val_flt) u32_ptr[idx]|=msk_f32_u32_one;
       } /* end else */
+    }else if(nco_baa_cnv_get() == nco_baa_dgr){
+      /* Digit Rounding (GCD19)
+	 Test DGR:
+	 ccc --tst=bnr --flt_foo=8 2> /dev/null | grep "Binary of float"
+	 ncks -O -C -D 1 --baa=3 -v ppc_bgr --ppc default=3 ~/nco/data/in.nc ~/foo.nc
+	 ncks -O -C -D 1 --baa=3 -v one_dmn_rec_var_flt --ppc default=3 ~/nco/data/in.nc ~/foo.nc */
+      unsigned char u8_xpn; /* dgr */
+      unsigned int u32_xpn; /* dgr */
+      unsigned int u32_dpl; /* dgr */
+      unsigned int msk_u32_xpn;
+      int i32_xpn; /* dgr */
+      int dgt_nbr_pre_dcm; /* Number of decimal digits before decimal point d_i in DCG19 (7) */
+      int qnt_pwr_xpn; /* Quantization power exponent p_i in DCG19 (6) */
+      float qnt_fct_flt; /* Quantization factor q_i in DCG19 (5) */
+      float val_qnt; /* Quantized value DCG19 (1) */
+      int sgn_val; /* Sign of  DCG19 (5) */
+      /* Create mask */
+      msk_u32_xpn=0u; /* Zero all bits */
+      msk_u32_xpn=~msk_u32_xpn; /* Turn all bits to ones */
+      msk_u32_xpn>>=24; /* Right-shift zeros into bits to be zerod, leave ones in exponent bits */
+      if(!has_mss_val){
+	for(idx=0L;idx<sz;idx+=2L){
+	  u32_xpn=u32_ptr[idx]; // Copy memory so bitshifting exponent to byte boundary does not corrupt original
+	  u32_xpn>>=bit_xpl_nbr_sgn_flt; // Bit-shift exponent to end of word
+	  u32_xpn&=msk_u32_xpn; // Mask to elimnate sign bit
+	  i32_xpn=(int)u32_xpn-ieee_xpn_fst_flt; // Subtract 127 to compensate for IEEE SP exponent bias
+	  /* Number of decimal digits before decimal point */
+	  //	  dgt_nbr_pre_dcm=(i32_xpn > 0) ? (int)((i32_xpn-1)*dcm_per_bit_dgt_prc)+1 : 0; /* d_i DCG19 (7) */
+	  dgt_nbr_pre_dcm=(int)((i32_xpn-1)*dcm_per_bit_dgt_prc)+1; /* d_i DCG19 (7) */
+	  qnt_pwr_xpn=(dgt_nbr_pre_dcm > nsd) ? (int)((dgt_nbr_pre_dcm-nsd)*bit_per_dcm_dgt_prc) : 0; /* p_i DCG19 (6) */
+	  qnt_fct_flt=pow(2,qnt_pwr_xpn); /* Quantization factor q_i DCG19 (5) (as floating point) */
+	  /* Quantize value */
+	  val_qnt=op1.fp[idx];
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val_qnt1 = %g\n",nco_prg_nm_get(),val_qnt);
+	  val_qnt=(int)(fabs(val_qnt)/qnt_fct_flt);
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val_qnt2 = %g\n",nco_prg_nm_get(),val_qnt);
+	  val_qnt+=0.5f;
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val_qnt3 = %g\n",nco_prg_nm_get(),val_qnt);
+	  val_qnt*=qnt_fct_flt;
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val_qnt4 = %g\n",nco_prg_nm_get(),val_qnt);
+	  val_qnt*=(op1.fp[idx] > 0) ? 1 : -1;
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val_qnt5 = %g\n",nco_prg_nm_get(),val_qnt);
+	  u32_dpl=u32_ptr[idx];
+	  // u32_dpl= /* Take absolute value by placing 0 in sign bit */
+	  u32_dpl>>=qnt_pwr_xpn; /* Divide by q_i same as right-shifting by p_i */
+	  	  
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val = %g, u32_xpn = %u, i32_xpn=%d, dgt_nbr_pre_dcm = d_i = %d, qnt_pwr_xpn = p_i = %d, qnt_fct_flt = q_i = %g\n",nco_prg_nm_get(),op1.fp[idx],u32_xpn,i32_xpn,dgt_nbr_pre_dcm,qnt_pwr_xpn,qnt_fct_flt);
+	} /* !idx */
+	for(idx=1L;idx<sz;idx+=2L){
+	  if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val = %g, u8_xpn_nbr = %hhu\n",nco_prg_nm_get(),op1.fp[idx],u8_xpn);
+	  if(u32_ptr[idx] != 0U) /* Never quantize upwards floating point values of zero */
+	    u32_ptr[idx]|=msk_f32_u32_one;
+	} /* !idx */
+      }else{
+	const float mss_val_flt=*mss_val.fp;
+	for(idx=0L;idx<sz;idx+=2L)
+	  if(op1.fp[idx] != mss_val_flt) u32_ptr[idx]&=msk_f32_u32_zro;
+	for(idx=1L;idx<sz;idx+=2L)
+	  if(op1.fp[idx] != mss_val_flt && u32_ptr[idx] != 0U) u32_ptr[idx]|=msk_f32_u32_one;
+      } /* end else */
+    }else if(nco_baa_cnv_get() == nco_baa_bg2){
+      /* Bit-Groom2: alternately shave and set LSBs with dynamic masks
+	 Test BG2:
+	 ccc --tst=bnr --flt_foo=8 2> /dev/null | grep "Binary of float"
+	 ncks -O -C -D 1 --baa=4 -v ppc_bgr --ppc default=3 ~/nco/data/in.nc ~/foo.nc
+	 ncks -O -C -D 1 --baa=4 -v one_dmn_rec_var_flt --ppc default=3 ~/nco/data/in.nc ~/foo.nc */
+      if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: DEBUG nco_ppc_bitmask() reports val = %g\n",nco_prg_nm_get(),op1.fp[idx]);
     }else abort();
     break;
   case NC_DOUBLE:
@@ -751,6 +821,20 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
 	for(idx=0L;idx<sz;idx++)
 	  if(op1.dp[idx] != mss_val_dbl && u64_ptr[idx] != 0UL) u64_ptr[idx]|=msk_f64_u64_one;
       } /* end else */
+    }else if(nco_baa_cnv_get() == nco_baa_bg2){
+      /* Bit-Groom: alternately shave and set LSBs with dynamic masks */
+      if(!has_mss_val){
+	for(idx=0L;idx<sz;idx+=2L) u64_ptr[idx]&=msk_f64_u64_zro;
+	for(idx=1L;idx<sz;idx+=2L)
+	  if(u64_ptr[idx] != 0UL) /* Never quantize upwards floating point values of zero */
+	    u64_ptr[idx]|=msk_f64_u64_one;
+      }else{
+	const double mss_val_dbl=*mss_val.dp;
+	for(idx=0L;idx<sz;idx+=2L)
+	  if(op1.dp[idx] != mss_val_dbl) u64_ptr[idx]&=msk_f64_u64_zro;
+	for(idx=1L;idx<sz;idx+=2L)
+	  if(op1.dp[idx] != mss_val_dbl && u64_ptr[idx] != 0UL) u64_ptr[idx]|=msk_f64_u64_one;
+      } /* end else */
     }else abort();
     break;
   case NC_INT: /* Do nothing for non-floating point types ...*/
